/*	Debug.h
*
*	Debugging stuff!
*
*	#define these as desired:
*		DEBUG_COMM_TYPE     class to use for serial output
*		DEBUG_COMM          variable name to use for serial output
*		DEBUG_LCD_TYPE      class to use for LCD output
*		DEBUG_LCD           variable name to use for LCD output
*	Output will go only to what's defined.
*
*	Revisions:
*		07-05-06	version 1 in master library
*		09-28-06	Log only to comm, inline function
*		04-18-07	header comments for DEBUG_COMM/LCD[_TYPE]
*
*	Written by Cathy Saxton
*	robotics@idleloop.com
*/

#pragma once

#ifdef DEBUG

void AssertProc(const char *pszFile, int line);
//void LogProc(const char *psz);

#ifdef DEBUG_COMM
/* transmit error messages on the serial connection */
#include "Comm.h"
extern DEBUG_COMM_TYPE DEBUG_COMM;
inline void LogProc(const char *psz)	{ DEBUG_COMM.PrintLn(psz); }
inline void LogPgmProc(const char *psz)	{ DEBUG_COMM.PrintPgmLn(psz); }
#else
#define LogProc(psz) { }
#define LogPgmProc(psz) { }
#endif

#define Assert(f)			{ if (!(f)) AssertProc(__FILE__, __LINE__); }
#define Debug(x)			x
#define Log(lgt, psz)		{ if (lgt) LogProc(psz); }
/* output string from progmem */
#define LogPgm(lgt, psz)	{ if (lgt) LogPgmProc(psz); }

#else

#define Assert(f)			{ }
#define Debug(x)
#define Log(lgt, psz)		{ }
#define LogPgm(lgt, psz)	{ }

#endif

/* convenient way to disable a Log statement */
#define LogX(lgt, psz) { }
