/*	eeprom.cpp
*
*	EEPROM reading and writing.
*
*	Revisions:
*		07-05-06	version 1 in master library
*
*	Written by Cathy Saxton
*	robotics@idleloop.com
*/

#include <avr/io.h>
#include <avr/eeprom.h>
#include <avr/interrupt.h>
#include "Util.h"
#include "Debug.h"
#include "EEPROM.h"

/* macros to write to and read from EEPROM */
#define EEPROMWriteByte(addr, byte) \
			eeprom_write_byte((uint8_t *)(addr), (byte))
#define EEPROMReadByte(addr) \
			eeprom_read_byte((uint8_t *)(addr))

void EEPROM::Write(ushort e, uchar b) const
{
	if (e != eNil)
		EEPROMWriteByte(e, b);
}

void EEPROM::WriteAb(ushort e, const void *pv, uchar cb) const
{
	const uchar *pb, *pbMac;

	for (pbMac = (pb = (const uchar *)pv) + cb; pb < pbMac; ++pb, ++e)
		Write(e, *pb);
}

/* read the byte stored at EEPROM address e */
uchar EEPROM::Read(ushort e) const
{
	if (e == eNil)
		return 0;
	return EEPROMReadByte(e);
}

void EEPROM::ReadAb(ushort e, void *pv, uchar cb) const
{
	uchar *pb, *pbMac;

	for (pbMac = (pb = (uchar *)pv) + cb; pb < pbMac; ++pb, ++e)
		*pb = Read(e);
}
