/*	Servo.h
*
*	Servo control via PWM using Timer/Counter.
*
*	#define one of the following values to select the appropriate code
*	based on your microcontroller and desired Timer/Counter (T/C) usage.
*
*	define  T/C   ATmega...
*	------- ---   --------------------
*	SERVO_1  1    8, 16, 32, 644, 128
*	SERVO_3  3    128
*
*	Revisions:
*		07-05-06	version 1 in master library
*
*	Written by Cathy Saxton
*	robotics@idleloop.com
*/

#pragma once

/* see Servo.cpp for calculations (microseconds / tick is based on
   timer/counter rate) */
#ifdef CLOCK_8M
const uint usPerTick = 8;
#elif defined CLOCK_16M
const uint usPerTick = 4;
#else
#error "unknown uC clock rate (see Servo.h, Util.h)"
#endif

/* calculate PWM value corresponding to specified number of microseconds */
#define PWMFromUs(us) ((us)/usPerTick)

enum	// Servo PWM Connection
{
	spcA,	// servo PWM connected to OCnA (or OCn) output
	spcB,	// servo PWM connected to OCnB output
	spcC,	// servo PWM connected to OCnC output
};

class SERVO
{
public:
	SERVO(char spc, ushort pwm);

	/* sets signal pulse width (i.e. servo position);
	   use PwmFromUs() macro... */
	void SetPWM(ushort pwm) const;

private:
	static void Init();

	volatile uint16_t *m_pregOCRnx;
	/* 16-bit SFR...
	   write: high, then low
	   read: low, then high
	*/

	/* static variable: one per class, not instance */
	static char s_fInit;
};
