/*	Globals.cpp
*
*	Includes and globals.
*
*	Revisions:
*		10-16-06	LDC8 instead of LCD (from library change)
*
*	Written by Cathy Saxton
*	robotics@idleloop.com
*/

#include <avr/pgmspace.h>
#include "main.h"

/*
*	Globals
*
*	These lines declare variables for using inputs, outputs, and
*	microcontroller features. Initialization of the appropriate
*	ports/pins is done by the class constructors. Declaring them
*	outside main() makes them globals, accessible from all
*	functions.
*/

#define regA &DDRA, &PORTA, &PINA
#define regB &DDRB, &PORTB, &PINB
#define regC &DDRC, &PORTC, &PINC
#define regD &DDRD, &PORTD, &PIND
#define regE &DDRE, &PORTE, &PINE
#define regF &DDRF, &PORTF, &PINF
#define regG &DDRG, &PORTG, &PING

char g_szBuf[17];

TIMER	g_timer;
EEPROM	g_eeprom;

COMM	g_comm(fTrue, fTrue);

IN		g_dip4		(regA, 0, fTrue);	// pin 51
IN		g_dip3		(regA, 1, fTrue);
IN		g_dip2		(regA, 2, fTrue);
IN		g_dip1		(regA, 3, fTrue);	// pin 48
IN		g_bumpR		(regA, 7, fTrue);	// pin 44

OUT		g_oc1a		(regB, 5, 0);		// pin 15
OUT		g_oc1b		(regB, 6, 0);		// pin 16
OUT		g_oc1c		(regB, 7, 0);		// pin 17

/* D0 = SCL, D1 = SDA */
/* D2 = Rx, D3 = Tx */
OUT		g_ledL		(regD, 6, 1);		// pin 31
OUT		g_ledR		(regD, 7, 1);		// pin 32

IN		g_bumpL		(regG, 2, fTrue);	// pin 43

SERVO	g_driveR	(spcA, PWMFromUs(1500));
SERVO	g_driveL	(spcB, PWMFromUs(1500));
SERVO	g_pickup	(spcC, PWMFromUs(1500));

/*
pins:
21, 52 VCC
22, 53 GND

SPI programming:
2  PDI PE0
3  PDO PE1
11 SCK PB1
20 RESET
*/
